@@ -9,6 +9,6 @@ See :ref:`Choose a hashing backend` for more.
 """
 
 SUPPORTED_BACKENDS = [
-    "pycryptodome",  # prefer this over pysha3, for pypy3 support
     "pysha3",
+    "pycryptodome",
 ]
